@@ -53,6 +53,9 @@ using namespace std;
 #include "netifyd.h"
 
 #include "nd-ndpi.h"
+#include "nd-risks.h"
+#include "nd-serializer.h"
+#include "nd-packet.h"
 #include "nd-json.h"
 #include "nd-util.h"
 #include "nd-thread.h"
